==> haskell-transformers-base-0.4.5.2-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-transformers-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: transformers-base
version: 0.4.5.2
id: transformers-base-0.4.5.2-KW6dpmOXA8I95CecmuGvJB
key: transformers-base-0.4.5.2-KW6dpmOXA8I95CecmuGvJB
license: BSD-3-Clause
copyright: 2011 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>,
           Bas van Dijk <v.dijk.bas@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>,
        Bas van Dijk <v.dijk.bas@gmail.com>
stability: experimental
homepage: https://github.com/mvv/transformers-base
synopsis: Lift computations from the bottom of a transformer stack
description:
    This package provides a straightforward port of @monadLib@'\''s BaseM
    typeclass to @transformers@.
category: Control
abi: a3b4f976cb4fc5cdc4f30a5f5505a094
exposed: True
exposed-modules:
    Control.Monad.Base
import-dirs: /usr/lib/ghc-8.4.3/site-local/transformers-base-0.4.5.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/transformers-base-0.4.5.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/transformers-base-0.4.5.2
hs-libraries: HStransformers-base-0.4.5.2-KW6dpmOXA8I95CecmuGvJB
depends:
    base-4.11.1.0 stm-2.4.5.0 transformers-0.5.5.0
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
    base-orphans-0.7-DFzqJo74HQjHjfhO0xkTzo
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             stm-2.4.5.0=cd8ccc9f17cf51980f6d59f12e77db7d
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=197a030c492741542d6f49bc76370bb8
             base-orphans-0.7-DFzqJo74HQjHjfhO0xkTzo=9502af04c7c3772a92a8cf1ef282323a
haddock-interfaces: /usr/share/doc/haskell-transformers-base/html/transformers-base.haddock
haddock-html: /usr/share/doc/haskell-transformers-base/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-transformers-base-0.4.5.2-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-transformers-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: transformers-base
version: 0.4.5.2
id: transformers-base-0.4.5.2-6bi821vJnyALiU5xNcgdNE
key: transformers-base-0.4.5.2-6bi821vJnyALiU5xNcgdNE
license: BSD-3-Clause
copyright: 2011 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>,
           Bas van Dijk <v.dijk.bas@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>,
        Bas van Dijk <v.dijk.bas@gmail.com>
stability: experimental
homepage: https://github.com/mvv/transformers-base
synopsis: Lift computations from the bottom of a transformer stack
description:
    This package provides a straightforward port of @monadLib@'\''s BaseM
    typeclass to @transformers@.
category: Control
abi: a83e875d96ef3a45a1077fdf83ced0a7
exposed: True
exposed-modules:
    Control.Monad.Base
import-dirs: /usr/lib/ghc-8.4.3/site-local/transformers-base-0.4.5.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/transformers-base-0.4.5.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/transformers-base-0.4.5.2
hs-libraries: HStransformers-base-0.4.5.2-6bi821vJnyALiU5xNcgdNE
depends:
    base-4.11.1.0 stm-2.4.5.0 transformers-0.5.5.0
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
    base-orphans-0.7-IbUmKuGo32q1xNHfJ3kINx
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             stm-2.4.5.0=cd8ccc9f17cf51980f6d59f12e77db7d
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=197a030c492741542d6f49bc76370bb8
             base-orphans-0.7-IbUmKuGo32q1xNHfJ3kINx=ba4bebebf98d294ff4d7d990288b1703
haddock-interfaces: /usr/share/doc/haskell-transformers-base/html/transformers-base.haddock
haddock-html: /usr/share/doc/haskell-transformers-base/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
